# iSeaborn
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/pseudoPixels/bokehBorn/master)
[![Documentation Status](https://readthedocs.org/projects/iseaborn/badge/?version=latest)](https://iseaborn.readthedocs.io/en/latest/?badge=latest)

